@@ -17,6 +17,7 @@ def objectify(dict):
 class SolaceResponse(Response):
     json = munch.munchify({})
     html = None
+    text = None
 
     def __init__(self, config = {}):
         super().__init__()
@@ -31,9 +32,9 @@ class SolaceResponse(Response):
         self.html = template.render(**context)
 
 class Solace:
-    
     def __init__(self, config = {}):
-        self.config = {}
+        self.cors = None
+        self.config = munch.munchify(config)
         self.rules = Map([])
         self.views = {}
     
@@ -111,23 +112,31 @@ class Solace:
         to a resource.
         """
         self.__rule('PATCH', urlpath, handler)
-
-    def register(self, Middleware):
-        pass
-
+    
     def __next_func(self, handler):
-        handler(self.req, self.res, self.__next_func)
+        handler(self.req, self.res)
 
     def __dispatch(self, req):
         adapter = self.rules.bind_to_environ(req.environ)
         self.req = req
+        self.req.next = self.__next_func
         self.res = SolaceResponse()
         try:
             endpoint, values = adapter.match()
             self.req.params = munch.munchify(values)
             if endpoint not in self.views:
                 raise NotFound
-            self.views[endpoint](self.req, self.res, self.__next_func)
+
+            # NOTE: this defines the signature for all request handlers...
+            self.views[endpoint](self.req, self.res)
+
+            # Enables CORS Support
+            # TODO: should we add a supported list of keys?
+            # or can this be open to adding any desired headers
+            # to every response?
+            if self.cors is not None:
+                for header in self.cors:
+                    self.res.headers.set(header, self.cors.get(header))
 
             if self.res.json:
                 self.res.content_type = "application/json"
@@ -138,16 +147,22 @@ class Solace:
                 self.res.content_type = "text/html"
                 self.res.data = self.res.html
                 return self.res
+            
+            if self.res.text:
+                self.res.content_type = "text/plain"
+                self.res.data = self.res.text
+                return self.res
 
             return self.res
         except HTTPException as e:
+            # TODO: offer an optional HTML error page to avoid showing JSON errors.
             err = {
                 'code': e.code,
                 'message': e.description
             }
             res = Response(json.dumps({"error": err}), e.code)
             res.content_type = 'application/json'
-            return res 
+            return res
 
     def __wsgi_app(self, environ, start_response):
         req = Request(environ)
