@@ -1,6 +1,6 @@
 import typer
-from .new import app as new
-from .run import app as run
+from .new import typ as new
+from .run import typ as run
 
 app = typer.Typer(add_completion=False)
 app.add_typer(new, name="new")
