@@ -6,10 +6,10 @@ typ = typer.Typer()
 ### Templates for our Scaffolding Features
 templateV1 = """from solace import Solace
 
-def greet_html(req, res, next):
+def greet_html(req, res):
     res.tpl("index.html", {"name": "World"})
 
-def greet_json(req, res, next):
+def greet_json(req, res):
     res.json = {"Hello": "World"}
 
 app = Solace()
@@ -22,7 +22,7 @@ app.get("/api", greet_json)
 ### Templates for our Scaffolding Features
 templateV2 = """from solace import Solace
 
-def greet_json(req, res, next):
+def greet_json(req, res):
     res.json = {"Hello": "World"}
 
 app = Solace()
